summaryrefslogtreecommitdiffstats
path: root/src/cli.rs
diff options
context:
space:
mode:
authorDan Davison <dandavison7@gmail.com>2020-06-26 19:37:45 -0400
committerDan Davison <dandavison7@gmail.com>2020-06-26 19:49:32 -0400
commitea7266594a7a470f98a309bb4c0da7359b2037e2 (patch)
treef083c695f11332f336ead8cf078c9251b9314ca3 /src/cli.rs
parent472c5a509d5cc9e57bad476e4cd852e4b9459a01 (diff)
New command --show-styles
Drop old command --show-background-colors
Diffstat (limited to 'src/cli.rs')
-rw-r--r--src/cli.rs12
1 files changed, 5 insertions, 7 deletions
diff --git a/src/cli.rs b/src/cli.rs
index 49caad24..01aa0fba 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -384,13 +384,11 @@ pub struct Opt {
#[structopt(long = "tabs", default_value = "4")]
pub tab_width: usize,
- /// Show the command-line arguments (RGB hex codes) for the background colors that are in
- /// effect. The hex codes are displayed with their associated background color. This option can
- /// be combined with --light and --dark to view the background colors for those modes. It can
- /// also be used to experiment with different RGB hex codes by combining this option with style
- /// options such as --minus-style, --zero-style, --plus-style, etc.
- #[structopt(long = "show-background-colors")]
- pub show_background_colors: bool,
+ /// Print the style strings for all style options. This can be used to experiment with
+ /// different colors by combining this option with other options such as --minus-style,
+ /// --zero-style, --plus-style, --light, --dark, etc.
+ #[structopt(long = "show-styles")]
+ pub show_styles: bool,
/// List supported languages and associated file extensions.
#[structopt(long = "list-languages")]